@@ -25,13 +25,15 @@
 
 package Bugzilla::Util;
 
+use strict;
+
 use base qw(Exporter);
 @Bugzilla::Util::EXPORT = qw(is_tainted trick_taint detaint_natural
-                             html_quote url_quote value_quote
+                             html_quote url_quote value_quote xml_quote
                              lsearch max min
-                             trim);
+                             trim format_time);
 
-use strict;
+use Bugzilla::Config;
 
 # This is from the perlsec page, slightly modifed to remove a warning
 # From that page:
@@ -87,6 +89,16 @@ sub value_quote {
     return $var;
 }
 
+sub xml_quote {
+    my ($var) = (@_);
+    $var =~ s/\&/\&amp;/g;
+    $var =~ s/</\&lt;/g;
+    $var =~ s/>/\&gt;/g;
+    $var =~ s/\"/\&quot;/g;
+    $var =~ s/\'/\&apos;/g;
+    return $var;
+}
+
 sub lsearch {
     my ($list,$item) = (@_);
     my $count = 0;
@@ -122,6 +134,36 @@ sub trim {
     return $str;
 }
 
+sub format_time {
+    my ($time) = @_;
+
+    my ($year, $month, $day, $hour, $min);
+    if ($time =~ m/^\d{14}$/) {
+        # We appear to have a timestamp direct from MySQL
+        $year  = substr($time,0,4);
+        $month = substr($time,4,2);
+        $day   = substr($time,6,2);
+        $hour  = substr($time,8,2);
+        $min   = substr($time,10,2);
+    }
+    elsif ($time =~ m/^(\d{4})\.(\d{2})\.(\d{2}) (\d{2}):(\d{2})(:\d{2})?$/) {
+        $year  = $1;
+        $month = $2;
+        $day   = $3;
+        $hour  = $4;
+        $min   = $5;
+    }
+    else {
+        warn "Date/Time format ($time) unrecogonzied";
+    }
+
+    if (defined $year) {
+        $time = "$year-$month-$day $hour:$min";
+        $time .= " " . &::Param('timezone') if &::Param('timezone');
+    }
+    return $time;
+}
+
 1;
 
 __END__
@@ -143,6 +185,7 @@ Bugzilla::Util - Generic utility functions for bugzilla
   html_quote($var);
   url_quote($var);
   value_quote($var);
+  xml_quote($var);
 
   # Functions for searching
   $loc = lsearch(\@arr, $val);
@@ -152,6 +195,9 @@ Bugzilla::Util - Generic utility functions for bugzilla
   # Functions for trimming variables
   $val = trim(" abc ");
 
+  # Functions for formatting time
+  format_time($time);
+
 =head1 DESCRIPTION
 
 This package contains various utility functions which do not belong anywhere
@@ -217,6 +263,12 @@ Quotes characters so that they may be included as part of a url.
 As well as escaping html like C<html_quote>, this routine converts newlines
 into &#013;, suitable for use in html attributes.
 
+=item C<xml_quote($val)>
+
+This is similar to C<html_quote>, except that ' is escaped to &apos;. This
+is kept separate from html_quote partly for compatibility with previous code
+(for &apos;) and partly for future handling of non-ASCII characters.
+
 =back
 
 =head2 Searching
@@ -252,3 +304,17 @@ Removes any leading or trailing whitespace from a string. This routine does not
 modify the existing string.
 
 =back
+
+=head2 Formatting Time
+
+=over 4
+
+=item C<format_time($time)>
+
+Takes a time and appends the timezone as defined in editparams.cgi.  This routine
+will be expanded in the future to adjust for user preferences regarding what
+timezone to display times in.  In the future, it may also allow for the time to be
+shown in different formats.
+
+=back
+
