@@ -219,7 +219,13 @@ sub get_netaddr {
     return join(".", unpack("CCCC", pack("N", $addr)));
 }
 
-sub quietly_check_login() {
+my $login_cookie_set = 0;
+# If quietly_check_login is called with no arguments and logins are
+# required, it will prompt for a login.
+sub quietly_check_login {
+    if (Param('requirelogin') && !(@_)) {
+        return confirm_login();
+    }
     $::disabledreason = '';
     my $userid = 0;
     my $ipaddr = $ENV{'REMOTE_ADDR'};
@@ -561,11 +567,19 @@ sub confirm_login {
 
        $::COOKIE{"Bugzilla_logincookie"} = $logincookie;
        my $cookiepath = Param("cookiepath");
-       print "Set-Cookie: Bugzilla_login= " . url_quote($enteredlogin) . " ; path=$cookiepath; expires=Sun, 30-Jun-2029 00:00:00 GMT\n";
-       print "Set-Cookie: Bugzilla_logincookie=$logincookie ; path=$cookiepath; expires=Sun, 30-Jun-2029 00:00:00 GMT\n";
+       if ($login_cookie_set == 0) {
+           $login_cookie_set = 1;
+           print "Set-Cookie: Bugzilla_login= " . url_quote($enteredlogin) . " ; path=$cookiepath; expires=Sun, 30-Jun-2029 00:00:00 GMT\n";
+           print "Set-Cookie: Bugzilla_logincookie=$logincookie ; path=$cookiepath; expires=Sun, 30-Jun-2029 00:00:00 GMT\n";
+       }
     }
 
-    $userid = quietly_check_login();
+    # If anonymous logins are disabled, quietly_check_login will force
+    # the user to log in by calling confirm_login() when called by any 
+    # code that does not call it with an argument. When confirm_login
+    # calls quietly_check_login, it must not result in confirm_login
+    # being called back.
+    $userid = quietly_check_login('do_not_recurse_here');
 
     if (!$userid) {
         if ($::disabledreason) {
@@ -797,7 +811,7 @@ sub GetBugActivity {
         SELECT IFNULL(fielddefs.description, bugs_activity.fieldid),
                 fielddefs.name,
                 bugs_activity.attach_id,
-                bugs_activity.bug_when,
+                DATE_FORMAT(bugs_activity.bug_when,'%Y.%m.%d %H:%i'),
                 bugs_activity.removed, bugs_activity.added,
                 profiles.login_name
         FROM bugs_activity LEFT JOIN fielddefs ON 
@@ -879,12 +893,10 @@ sub GetBugActivity {
 
 ############# Live code below here (that is, not subroutine defs) #############
 
-use Bugzilla::CGI();
+use Bugzilla;
 
-# XXX - mod_perl, this needs to move into all the scripts individually
-# Once we do that, look into setting DISABLE_UPLOADS, and overriding
-# on a per-script basis
-$::cgi = new Bugzilla::CGI();
+# XXX - mod_perl - reset this between runs
+$::cgi = Bugzilla->instance->cgi;
 
 # Set up stuff for compatibility with the old CGI.pl code
 # This code will be removed as soon as possible, in favour of
@@ -904,4 +916,7 @@ foreach my $name ($::cgi->cookie()) {
     $::COOKIE{$name} = $::cgi->cookie($name);
 }
 
+# This could be needed in any CGI, so we set it here.
+$vars->{'help'} = $::cgi->param('help') ? 1 : 0;
+
 1;
