@@ -54,7 +54,7 @@ foreach (@myproducts) {
 &calculate_dupes();
 
 # Generate a static RDF file containing the default view of the duplicates data.
-open(CGI, "REQUEST_METHOD=GET QUERY_STRING=ctype=rdf ./duplicates.cgi |")
+open(CGI, "GATEWAY_INTERFACE=cmdline REQUEST_METHOD=GET QUERY_STRING=ctype=rdf ./duplicates.cgi |")
   || die "can't fork duplicates.cgi: $!";
 open(RDF, ">data/duplicates.tmp")
   || die "can't write to data/duplicates.tmp: $!";
@@ -73,7 +73,7 @@ if (-s "data/duplicates.tmp") {
 sub check_data_dir {
     my $dir = shift;
 
-    if (! -d) {
+    if (! -d $dir) {
         mkdir $dir, 0777;
         chmod 0777, $dir;
     }
