@@ -67,30 +67,14 @@ sub check_shadowdb {
     if ($value eq "") {
         return "";
     }
-    if (!Param("updateshadowdb")) {
-        # Can't test this, because ConnectToDatabase uses the param, but
-        # we can't set this before testing....
-        return "";
-    }
-    &::SendSQL("SHOW DATABASES");
-    while (&::MoreSQLData()) {
-        my $n = &::FetchOneColumn();
-        if (lc($n) eq lc($value)) {
-            return "The $n database already exists.  If that's really the name you want to use for the backup, please CAREFULLY make the existing database go away somehow, and then try again.";
-        }
-    }
-    # We trust the admin....
-    trick_taint($value);
-    &::SendSQL("CREATE DATABASE $value");
-    &::SendSQL("INSERT INTO shadowlog (command) VALUES ('SYNCUP')", 1);
-    return "";
-}
 
-sub check_shadowdbhost {
-    my ($value) = (@_);
-    if ($value && Param("updateshadowdb")) {
-        return "Sorry, you can't have the shadowdb on a different connection to the main database if you want Bugzilla to handle the replication for you.";
+    if (!Param('shadowdbhost')) {
+        return "You need to specify a host when using a shadow database";
     }
+
+    # Can't test existance of this because ConnectToDatabase uses the param,
+    # but we can't set this before testing....
+    # This can really only be fixed after we can use the DBI more openly
     return "";
 }
 
@@ -213,7 +197,7 @@ sub check_netmask {
    desc => 'The URL that is the common initial leading part of all Bugzilla ' .
            'URLs.',
    type => 't',
-   default => 'http://cvs-mirror.mozilla.org/webtools/bugzilla/',
+   default => 'http://you-havent-visited-editparams.cgi-yet/',
    checker => \&check_urlbase
   },
 
@@ -230,6 +214,14 @@ sub check_netmask {
    default => '/'
   },
 
+  {
+   name => 'timezone',
+   desc => 'The timezone that your database server lives in. If set to "", ' .
+           'then the timezone won\'t be displayed with the timestamps.',
+   type => 't',
+   default => '',
+  },
+
   {
    name => 'enablequips',
    desc => 'Controls the appearance of quips at the top of buglists.<ul> ' .
@@ -244,7 +236,7 @@ sub check_netmask {
   },
 
   {
-   name => 'usebuggroups',
+   name => 'makeproductgroups',
    desc => 'If this is on, Bugzilla will associate a bug group with each ' .
            'product in the database, and use it for querying bugs.',
    type => 'b',
@@ -252,58 +244,21 @@ sub check_netmask {
   },
 
   {
-   name => 'usebuggroupsentry',
-   desc => 'If this is on, Bugzilla will use product bug groups to restrict ' .
-           'who can enter bugs.  Requires usebuggroups to be on as well.',
+   name => 'useentrygroupdefault',
+   desc => 'If this is on, Bugzilla will use product bug groups by default ' .
+           'to restrict who can enter bugs. If this is on, users can see ' .
+           'any product to which they have entry access in search menus. ' .
+           'If this is off, users can see any product to which they have not ' .
+           'been excluded by a mandatory restriction.',
    type => 'b',
    default => 0
   },
 
-  {
-   name => 'queryagainstshadowdb',
-   desc => 'If this is on, and the <tt>shadowdb</tt> parameter is set, then ' .
-           'certain queries will happen against the shadow database.',
-   type => 'b',
-   default => 0,
-  },
-
-  {
-   name => 'updateshadowdb',
-   desc => 'If this is on, and the <tt>shadowdb</tt> parameter is set, then ' .
-           'Bugzilla will use the old style of shadow database in which it ' .
-           'manually propogates changes to the shadow database. Otherwise, ' .
-           'Bugzilla will assume that the <tt>shadowdb</tt> database (if ' . 
-           'any) is being updated via replication. <b>WARNING! This ' .
-           'manual replication is deprecated and is going away soon ' .
-           '(<u>BEFORE</u> the next stable Bugzilla release).</b> It has ' .
-           'several problems with data consistency, and replication is the ' .
-           'preferred option. If this parameter is on, and you disable it, ' .
-           'make sure that the shadow database is already set up for ' .
-           'replication, or queries will return stale data.',
-   type => 'b',
-   default => 1,
-  },
-
-  # This entry must be _after_ updateshadowdb, because check_shadowdbhost uses
-  # that
   {
    name => 'shadowdbhost',
-   desc => 'The host the shadow database is on. If blank, then then we ' .
-           'assume it\'s on the main database host (as defined in ' .
-           'localconfig) and ingore the <tt>shadowdbport</tt> and ' .
-           '<tt>shadowdbsock</tt> parameters below, which means that this ' .
-           'parameter <em>must be filled in</em> if your shadow database is ' .
-           'on a different instance of the mysql server, even if that ' .
-           'instance runs on the same machine as the main database. Note ' .
-           'that <tt>updateshadowdb</tt> must be off if the shadow database ' .
-           'is on a difference mysql instance, since Bugzilla can\'t ' .
-           'propogate changes between instances itself, and this should be ' .
-           'left blank if the shadow database is on the same instance, ' .
-           'since Bugzilla can then reuse the same database connection for '.
-           'better performance.',
+   desc => 'The host the shadow database is on.',
    type => 't',
    default => '',
-   checker => \&check_shadowdbhost,
   },
 
   {
@@ -335,11 +290,12 @@ sub check_netmask {
   {
    name => 'shadowdb',
    desc => 'If non-empty, then this is the name of another database in ' .
-           'which Bugzilla will keep a shadow read-only copy of everything. ' .
+           'which Bugzilla will use as a read-only copy of everything. ' .
            'This is done so that long slow read-only operations can be used ' .
-           'against this db, and not lock up things for everyone else. ' .
-           'Turning on this parameter will create the given database ; be ' .
-           'careful not to use the name of an existing database with useful ' .           'data in it!',
+           'against this db, and not lock up things for everyone else. This ' .
+           'database is on the <tt>shadowdbhost</tt>, and must exist. ' .
+           'Bugzilla does not update it, if you use this paramater, then ' .
+           'you need to set up replication for your database',
    type => 't',
    default => '',
    checker => \&check_shadowdb
@@ -685,6 +641,19 @@ You will get this message once a day until you\'ve dealt with these bugs!
    default => ''
   },
 
+  {
+   name => 'createemailregexp',
+   desc => 'This defines the regexp to use for email addresses that are ' .
+           'permitted to self-register using a "New Account" feature. The ' .
+           'default (.*) permits any account matching the emailregexp ' .
+           'to be created.  If this parameter is left blank, no users ' .
+           'will be permitted to create their own accounts and all accounts ' .
+           'will have to be created by an administrator',
+   type => 't',
+   default => q:.*:,
+   checker => \&check_regexp
+  },
+
   {
    name => 'voteremovedmail',
    desc => 'This is a mail message to send to anyone who gets a vote removed ' .
@@ -963,6 +932,15 @@ Reason: %reason%
    checker => \&check_netmask
   },
 
+  {
+   name => 'requirelogin',
+   desc => 'If this option is set, all access to the system beyond the ' .
+           ' front page will require a login. No anonymous users will ' .
+           ' be permitted.',
+   type => 'b',
+   default => '0'
+  },
+
   {
    name => 'usermatchmode',
    desc => 'Allow match strings to be entered for user names when entering ' .
