@@ -28,6 +28,7 @@
 
 use strict;
 
+use Bugzilla::Constants;
 use Bugzilla::Util;
 # Bring ChmodDataFile in until this is all moved to the module
 use Bugzilla::Config qw(:DEFAULT ChmodDataFile);
@@ -108,19 +109,16 @@ $::dbwritesallowed = 1;
 sub ConnectToDatabase {
     my ($useshadow) = (@_);
     $::dbwritesallowed = !$useshadow;
-    $useshadow = ($useshadow && Param("shadowdb") &&
-                  Param("queryagainstshadowdb"));
-    my $useshadow_dbh = ($useshadow && Param("shadowdbhost") ne "");
-    my $name = $useshadow ? Param("shadowdb") : $::db_name;
+    $useshadow &&= Param("shadowdb");
     my $connectstring;
 
-    if ($useshadow_dbh) {
+    if ($useshadow) {
         if (defined $::shadow_dbh) {
             $::db = $::shadow_dbh;
             return;
         }
         $connectstring="DBI:mysql:host=" . Param("shadowdbhost") .
-          ";database=$name;port=" . Param("shadowdbport");
+          ";database=" . Param('shadowdb') . ";port=" . Param("shadowdbport");
         if (Param("shadowdbsock") ne "") {
             $connectstring .= ";mysql_socket=" . Param("shadowdbsock");
         }
@@ -129,7 +127,7 @@ sub ConnectToDatabase {
             $::db = $::main_dbh;
             return;
         }
-        $connectstring="DBI:mysql:host=$::db_host;database=$name;port=$::db_port";
+        $connectstring="DBI:mysql:host=$::db_host;database=$::db_name;port=$::db_port";
         if ($::db_sock ne "") {
             $connectstring .= ";mysql_socket=$::db_sock";
         }
@@ -140,7 +138,7 @@ sub ConnectToDatabase {
         Param("maintainer") . ". The error you should quote is: " .
         $DBI::errstr;
 
-    if ($useshadow_dbh) {
+    if ($useshadow) {
         $::shadow_dbh = $::db;
     } else {
         $::main_dbh = $::db;
@@ -148,58 +146,17 @@ sub ConnectToDatabase {
 }
 
 sub ReconnectToShadowDatabase {
-    # This will connect us to the shadowdb if we're not already connected,
-    # but if we're using the same dbh for both the main db and the shadowdb,
-    # be sure to USE the correct db
-    if (Param("shadowdb") && Param("queryagainstshadowdb")) {
+    if (Param("shadowdb")) {
         ConnectToDatabase(1);
-        if (!Param("shadowdbhost")) {
-            SendSQL("USE " . Param("shadowdb"));
-        }
     }
 }
 
 sub ReconnectToMainDatabase {
-    if (Param("shadowdb") && Param("queryagainstshadowdb")) {
+    if (Param("shadowdb")) {
         ConnectToDatabase();
-        if (!Param("shadowdbhost")) {
-            SendSQL("USE $::db_name");
-        }
     }
 }
 
-my $shadowchanges = 0;
-sub SyncAnyPendingShadowChanges {
-    if ($shadowchanges && Param("updateshadowdb")) {
-        my $pid;
-        FORK: {
-            if ($pid = fork) { # create a fork
-                # parent code runs here
-                $shadowchanges = 0;
-                return;
-            } elsif (defined $pid) {
-                # child process code runs here
-                my $redir = ($^O =~ /MSWin32/i) ? "NUL" : "/dev/null";
-                open STDOUT,">$redir";
-                open STDERR,">$redir";
-                exec("./syncshadowdb","--") or die "Unable to exec syncshadowdb: $!";
-                # the idea was that passing the second parameter tricks it into
-                # using execvp instead of running a shell. Not really necessary since
-                # there are no shell meta-characters, but it passes our tinderbox
-                # test that way. :) http://bugzilla.mozilla.org/show_bug.cgi?id=21253
-            } elsif ($! =~ /No more process/) {
-                # recoverable fork error, try again in 5 seconds
-                sleep 5;
-                redo FORK;
-            } else {
-                # something weird went wrong
-                die "Can't create background process to run syncshadowdb: $!";
-            }
-        }
-    }
-}
-
-
 # This is used to manipulate global state used by SendSQL(),
 # MoreSQLData() and FetchSQLData().  It provides a way to do another
 # SQL query without losing any as-yet-unfetched data from an existing
@@ -247,7 +204,7 @@ sub SqlLog {
 }
 
 sub SendSQL {
-    my ($str, $dontshadow) = (@_);
+    my ($str) = (@_);
 
     # Don't use DBI's taint stuff yet, because:
     # a) We don't want out vars to be tainted (yet)
@@ -261,12 +218,10 @@ sub SendSQL {
     if ($iswrite && !$::dbwritesallowed) {
         die "Evil code attempted to write '$str' to the shadow database";
     }
-    if ($str =~ /^LOCK TABLES/i && $str !~ /shadowlog/ && $::dbwritesallowed) {
-        $str =~ s/^LOCK TABLES/LOCK TABLES shadowlog WRITE, /i;
-    }
+
     # If we are shutdown, we don't want to run queries except in special cases
     if (Param('shutdownhtml')) {
-        if ($0 =~ m:[\\/]((do)?editparams.cgi|syncshadowdb)$:) {
+        if ($0 =~ m:[\\/]((do)?editparams.cgi)$:) {
             $::ignorequery = 0;
         } else {
             $::ignorequery = 1;
@@ -283,19 +238,6 @@ sub SendSQL {
         die "$str: " . $errstr;
     }
     SqlLog("Done");
-    if (!$dontshadow && $iswrite && Param("shadowdb") && Param("updateshadowdb")) {
-        my $q = SqlQuote($str);
-        my $insertid;
-        if ($str =~ /^(INSERT|REPLACE)/i) {
-            SendSQL("SELECT LAST_INSERT_ID()");
-            $insertid = FetchOneColumn();
-        }
-        SendSQL("INSERT INTO shadowlog (command) VALUES ($q)", 1);
-        if ($insertid) {
-            SendSQL("SET LAST_INSERT_ID = $insertid");
-        }
-        $shadowchanges++;
-    }
 }
 
 sub MoreSQLData {
@@ -333,8 +275,9 @@ sub FetchOneColumn {
 
     
 
-@::default_column_list = ("severity", "priority", "platform", "owner",
-                          "status", "resolution", "summary");
+@::default_column_list = ("bug_severity", "priority", "rep_platform", 
+                          "assigned_to", "bug_status", "resolution",
+                          "short_short_desc");
 
 sub AppendComment {
     my ($bugid, $who, $comment, $isprivate, $timestamp, $work_time) = @_;
@@ -684,6 +627,171 @@ sub GenerateRandomPassword {
     return $password;
 }
 
+#
+# This function checks if there are any entry groups defined.
+# If called with no arguments, it identifies
+# entry groups for all products.  If called with a product
+# id argument, it checks for entry groups associated with 
+# one particular product.
+sub AnyEntryGroups {
+    my $product_id = shift;
+    $product_id = 0 unless ($product_id);
+    return $::CachedAnyEntryGroups{$product_id} 
+        if defined($::CachedAnyEntryGroups{$product_id});
+    PushGlobalSQLState();
+    my $query = "SELECT 1 FROM group_control_map WHERE entry != 0";
+    $query .= " AND product_id = $product_id" if ($product_id);
+    $query .= " LIMIT 1";
+    SendSQL($query);
+    $::CachedAnyEntryGroups{$product_id} = MoreSQLData();
+    FetchSQLData();
+    PopGlobalSQLState();
+    return $::CachedAnyEntryGroups{$product_id};
+}
+
+#
+# This function checks if there are any default groups defined.
+# If so, then groups may have to be changed when bugs move from
+# one bug to another.
+sub AnyDefaultGroups {
+    return $::CachedAnyDefaultGroups if defined($::CachedAnyDefaultGroups);
+    PushGlobalSQLState();
+    SendSQL("SELECT 1 FROM group_control_map, groups WHERE " .
+            "groups.id = group_control_map.group_id " .
+            "AND isactive != 0 AND " .
+            "(membercontrol = " . CONTROLMAPDEFAULT .
+            " OR othercontrol = " . CONTROLMAPDEFAULT .
+            ") LIMIT 1");
+    $::CachedAnyDefaultGroups = MoreSQLData();
+    FetchSQLData();
+    PopGlobalSQLState();
+    return $::CachedAnyDefaultGroups;
+}
+
+#
+# This function checks if, given a product id, the user can edit
+# bugs in this product at all.
+sub CanEditProductId {
+    my ($productid) = @_;
+    my $query = "SELECT group_id FROM group_control_map " .
+                "WHERE product_id = $productid " .
+                "AND canedit != 0 "; 
+    if ((defined @{$::vars->{user}{groupids}}) 
+        && (@{$::vars->{user}{groupids}} > 0)) {
+        $query .= "AND group_id NOT IN(" . 
+                   join(',',@{$::vars->{user}{groupids}}) . ") ";
+    }
+    $query .= "LIMIT 1";
+    PushGlobalSQLState();
+    SendSQL($query);
+    my ($result) = FetchSQLData();
+    PopGlobalSQLState();
+    return (!defined($result));
+}
+
+#
+# This function determines if a user can enter bugs in the named
+# product.
+sub CanEnterProduct {
+    my ($productname) = @_;
+    my $query = "SELECT group_id IS NULL " .
+                "FROM products " .
+                "LEFT JOIN group_control_map " .
+                "ON group_control_map.product_id = products.id " .
+                "AND group_control_map.entry != 0 ";
+    if ((defined @{$::vars->{user}{groupids}}) 
+        && (@{$::vars->{user}{groupids}} > 0)) {
+        $query .= "AND group_id NOT IN(" . 
+                   join(',',@{$::vars->{user}{groupids}}) . ") ";
+    }
+    $query .= "WHERE products.name = " . SqlQuote($productname) . " LIMIT 1";
+    PushGlobalSQLState();
+    SendSQL($query);
+    my ($ret) = FetchSQLData();
+    PopGlobalSQLState();
+    return ($ret);
+}
+
+#
+# This function returns an alphabetical list of product names to which
+# the user can enter bugs.
+sub GetSelectableProducts {
+    my $query = "SELECT name " .
+                "FROM products " .
+                "LEFT JOIN group_control_map " .
+                "ON group_control_map.product_id = products.id ";
+    if (Param('useentrygroupdefault')) {
+        $query .= "AND group_control_map.entry != 0 ";
+    } else {
+        $query .= "AND group_control_map.membercontrol = " .
+                  CONTROLMAPMANDATORY . " ";
+    }
+    if ((defined @{$::vars->{user}{groupids}}) 
+        && (@{$::vars->{user}{groupids}} > 0)) {
+        $query .= "AND group_id NOT IN(" . 
+                   join(',',@{$::vars->{user}{groupids}}) . ") ";
+    }
+    $query .= "WHERE group_id IS NULL ORDER BY name";
+    PushGlobalSQLState();
+    SendSQL($query);
+    my @products = ();
+    while (MoreSQLData()) {
+        push @products,FetchOneColumn();
+    }
+    PopGlobalSQLState();
+    return (@products);
+}
+
+# GetSelectableProductHash
+# returns a hash containing 
+# legal_products => an enterable product list
+# legal_components => the list of components of enterable products
+# components => a hash of component lists for each enterable product
+sub GetSelectableProductHash {
+    my $query = "SELECT products.name, components.name " .
+                "FROM products " .
+                "LEFT JOIN components " .
+                "ON components.product_id = products.id " .
+                "LEFT JOIN group_control_map " .
+                "ON group_control_map.product_id = products.id ";
+    if (Param('useentrygroupdefault')) {
+        $query .= "AND group_control_map.entry != 0 ";
+    } else {
+        $query .= "AND group_control_map.membercontrol = " .
+                  CONTROLMAPMANDATORY . " ";
+    }
+    if ((defined @{$::vars->{user}{groupids}}) 
+        && (@{$::vars->{user}{groupids}} > 0)) {
+        $query .= "AND group_id NOT IN(" . 
+                   join(',', @{$::vars->{user}{groupids}}) . ") ";
+    }
+    $query .= "WHERE group_id IS NULL " .
+              "ORDER BY products.name, components.name";
+    PushGlobalSQLState();
+    SendSQL($query);
+    my @products = ();
+    my %components = ();
+    my %components_by_product = ();
+    while (MoreSQLData()) {
+        my ($product, $component) = FetchSQLData();
+        if (!grep($_ eq $product, @products)) {
+            push @products, $product;
+        }
+        if ($component) {
+            $components{$component} = 1;
+            push @{$components_by_product{$product}}, $component;
+        }
+    }
+    PopGlobalSQLState();
+    my @componentlist = (sort keys %components);
+    return {
+        legal_products => \@products,
+        legal_components => \@componentlist,
+        components => \%components_by_product,
+    };
+}
+
+
 sub CanSeeBug {
 
     my ($id, $userid) = @_;
@@ -1138,7 +1246,7 @@ sub GetLongDescriptionAsText {
     my $result = "";
     my $count = 0;
     my $anyprivate = 0;
-    my ($query) = ("SELECT profiles.login_name, longdescs.bug_when, " .
+    my ($query) = ("SELECT profiles.login_name, DATE_FORMAT(longdescs.bug_when,'%Y.%d.%m %H:%i'), " .
                    "       longdescs.thetext, longdescs.isprivate " .
                    "FROM   longdescs, profiles " .
                    "WHERE  profiles.userid = longdescs.who " .
@@ -1160,7 +1268,7 @@ sub GetLongDescriptionAsText {
         my ($who, $when, $text, $isprivate, $work_time) = (FetchSQLData());
         if ($count) {
             $result .= "\n\n------- Additional Comments From $who".Param('emailsuffix')."  ".
-                time2str("%Y-%m-%d %H:%M", str2time($when)) . " -------\n";
+                Bugzilla::Util::format_time($when) . " -------\n";
         }
         if (($isprivate > 0) && Param("insidergroup")) {
             $anyprivate = 1;
@@ -1176,7 +1284,7 @@ sub GetComments {
     my ($id) = (@_);
     my @comments;
     SendSQL("SELECT  profiles.realname, profiles.login_name, 
-                     date_format(longdescs.bug_when,'%Y-%m-%d %H:%i'), 
+                     date_format(longdescs.bug_when,'%Y.%m.%d %H:%i'), 
                      longdescs.thetext, longdescs.work_time,
                      isprivate,
                      date_format(longdescs.bug_when,'%Y%m%d%H%i%s') 
@@ -1558,133 +1666,7 @@ sub FormatTimeUnit {
     return $newtime;
     
 }
-###############################################################################
-# Global Templatization Code
 
-# Use the template toolkit (http://www.template-toolkit.org/) to generate
-# the user interface using templates in the "template/" subdirectory.
-use Template;
-
-# Create the global template object that processes templates and specify
-# configuration parameters that apply to all templates processed in this script.
-
-# IMPORTANT - If you make any configuration changes here, make sure to make
-# them in t/004.template.t and checksetup.pl. You may also need to change the
-# date settings were last changed - see the comments in checksetup.pl for
-# details
-$::template ||= Template->new(
-  {
-    # Colon-separated list of directories containing templates.
-    INCLUDE_PATH => "template/en/custom:template/en/default" ,
-
-    # Remove white-space before template directives (PRE_CHOMP) and at the
-    # beginning and end of templates and template blocks (TRIM) for better 
-    # looking, more compact content.  Use the plus sign at the beginning 
-    # of directives to maintain white space (i.e. [%+ DIRECTIVE %]).
-    PRE_CHOMP => 1 ,
-    TRIM => 1 , 
-
-    COMPILE_DIR => 'data/',
-
-    # Functions for processing text within templates in various ways.
-    # IMPORTANT!  When adding a filter here that does not override a
-    # built-in filter, please also add a stub filter to checksetup.pl
-    # and t/004template.t.
-    FILTERS =>
-      {
-        # Render text in strike-through style.
-        strike => sub { return "<strike>" . $_[0] . "</strike>" } ,
-
-        # Returns the text with backslashes, single/double quotes,
-        # and newlines/carriage returns escaped for use in JS strings.
-        js => sub
-        {
-            my ($var) = @_;
-            $var =~ s/([\\\'\"])/\\$1/g; 
-            $var =~ s/\n/\\n/g; 
-            $var =~ s/\r/\\r/g; 
-            return $var;
-        } , 
-
-        # HTML collapses newlines in element attributes to a single space,
-        # so form elements which may have whitespace (ie comments) need
-        # to be encoded using &#013;
-        # See bugs 4928, 22983 and 32000 for more details
-        html_linebreak => sub
-        {
-            my ($var) = @_;
-            $var =~ s/\r\n/\&#013;/g;
-            $var =~ s/\n\r/\&#013;/g;
-            $var =~ s/\r/\&#013;/g;
-            $var =~ s/\n/\&#013;/g;
-            return $var;
-        } ,
-
-        # This subroutine in CGI.pl escapes characters in a variable
-        # or value string for use in a query string.  It escapes all
-        # characters NOT in the regex set: [a-zA-Z0-9_\-.].  The 'uri'
-        # filter should be used for a full URL that may have
-        # characters that need encoding.
-        url_quote => \&Bugzilla::Util::url_quote,
-        
-        # In CSV, quotes are doubled, and we enclose the whole value in quotes
-        csv => sub
-        {
-            my ($var) = @_;
-            $var =~ s/"/""/g;
-            if ($var !~ /^-?(\d+\.)?\d*$/) {
-                $var = "\"$var\"";
-            }
-            return $var;
-        } ,
-      } ,
-  }
-) || die("Template creation failed: " . Template->error());
-
-# Use the Toolkit Template's Stash module to add utility pseudo-methods
-# to template variables.
-use Template::Stash;
-
-# Add "contains***" methods to list variables that search for one or more 
-# items in a list and return boolean values representing whether or not 
-# one/all/any item(s) were found.
-$Template::Stash::LIST_OPS->{ contains } =
-  sub {
-      my ($list, $item) = @_;
-      return grep($_ eq $item, @$list);
-  };
-
-$Template::Stash::LIST_OPS->{ containsany } =
-  sub {
-      my ($list, $items) = @_;
-      foreach my $item (@$items) { 
-          return 1 if grep($_ eq $item, @$list);
-      }
-      return 0;
-  };
-
-# Add a "substr" method to the Template Toolkit's "scalar" object
-# that returns a substring of a string.
-$Template::Stash::SCALAR_OPS->{ substr } = 
-  sub {
-      my ($scalar, $offset, $length) = @_;
-      return substr($scalar, $offset, $length);
-  };
-    
-# Add a "truncate" method to the Template Toolkit's "scalar" object
-# that truncates a string to a certain length.
-$Template::Stash::SCALAR_OPS->{ truncate } = 
-  sub {
-      my ($string, $length, $ellipsis) = @_;
-      $ellipsis ||= "";
-      
-      return $string if !$length || length($string) <= $length;
-      
-      my $strlen = $length - length($ellipsis);
-      my $newstr = substr($string, 0, $strlen) . $ellipsis;
-      return $newstr;
-  };
-    
 ###############################################################################
 
 # Constructs a format object from URL parameters. You most commonly call it 
@@ -1692,62 +1674,35 @@ $Template::Stash::SCALAR_OPS->{ truncate } =
 # my $format = GetFormat("foo/bar", $::FORM{'format'}, $::FORM{'ctype'});
 sub GetFormat {
     my ($template, $format, $ctype) = @_;
-    
+
     $ctype ||= "html";
     $format ||= "";
-    
+
     # Security - allow letters and a hyphen only
     $ctype =~ s/[^a-zA-Z\-]//g;
     $format =~ s/[^a-zA-Z\-]//g;
     trick_taint($ctype);
     trick_taint($format);
-    
+
     $template .= ($format ? "-$format" : "");
     $template .= ".$ctype.tmpl";
-        
-    return 
-    { 
-        'template'    => $template , 
-        'extension'   => $ctype , 
-        'ctype' => $::contenttypes->{$ctype} || "text/plain" , 
+
+    return
+    {
+        'template'    => $template ,
+        'extension'   => $ctype ,
+        'ctype' => $::contenttypes->{$ctype} || "text/plain" ,
     };
 }
 
-###############################################################################
+############# Live code below here (that is, not subroutine defs) #############
 
-# Define the global variables and functions that will be passed to the UI
-# template.  Additional values may be added to this hash before templates
-# are processed.
-$::vars =
-  {
-    # Function for retrieving global parameters.
-    'Param' => \&Param ,
+use Bugzilla;
 
-    # Function to create date strings
-    'time2str' => \&time2str ,
+$::BZ = Bugzilla->create();
 
-    # Function for processing global parameters that contain references
-    # to other global parameters.
-    'PerformSubsts' => \&PerformSubsts ,
-
-    # Generic linear search function
-    'lsearch' => \&Bugzilla::Util::lsearch ,
-
-    # quoteUrls - autolinkifies text
-    'quoteUrls' => \&quoteUrls ,
-    
-    # UserInGroup - you probably want to cache this
-    'UserInGroup' => \&UserInGroup ,
-
-    # SyncAnyPendingShadowChanges - called in the footer to sync the shadowdb
-    'SyncAnyPendingShadowChanges' => \&SyncAnyPendingShadowChanges ,
-    
-    # User Agent - useful for detecting in templates
-    'user_agent' => $ENV{'HTTP_USER_AGENT'} ,
-
-    # Bugzilla version
-    'VERSION' => $Bugzilla::Config::VERSION,
-  };
+$::template = $::BZ->template();
 
+$::vars = {};
 
 1;
