@@ -27,16 +27,13 @@ use strict;
 use Test::Harness qw(&runtests $verbose);
 
 $verbose = 0;
-my $onlytest = "";
 
 foreach (@ARGV) {
     if (/^(?:-v|--verbose)$/) {
         $verbose = 1;
-    }
-    else {
-        $onlytest = $_;
+        last;
     }
 }
 
-runtests(glob("t/$onlytest*.t"));
+runtests(glob("t/*.t"));
 
